.. _index:

=============
Documentation
=============

:mod:`Products.LDAPConnector` provides an abstraction layer on top 
of :term:`python-ldap`. It offers a connection object with simplified 
methods for inserting, modifying, searching and deleting records in the 
LDAP directory tree. Failover/redundancy can be achieved by supplying 
connection data for more than one LDAP server.

Narrative documentation
-----------------------

Narrative documentation explaining how to use :mod:`Products.LDAPConnector`.

.. toctree::
   :maxdepth: 2

   install
   usage_zmi
   usage_python
   stringencoding
   development
   changes

API documentation
-----------------

API documentation for :mod:`Products.LDAPConnector`.

.. toctree::
   :maxdepth: 2

   api

Support
-------

If you need commercial support for this software package, please
contact zetwork GmbH at `http://www.zetwork.com 
<http://www.zetwork.com/>`_.

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`
* :ref:`glossary`

